@@ -5,7 +5,7 @@
 #
 # Written and maintained by Michal Zalewski <lcamtuf@google.com>
 #
-# Copyright 2013, 2014 Google Inc. All rights reserved.
+# Copyright 2013, 2014, 2017 Google Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,18 +28,16 @@ echo
 ulimit -v 100000 2>/dev/null
 ulimit -d 100000 2>/dev/null
 
-if [ ! "$#" = "2" ]; then
-  echo "Usage: $0 /path/to/afl_output_dir /path/to/tested_binary" 1>&2
-  echo 1>&2
-  echo "Note: the tested binary must accept input on stdin and require no additional" 1>&2
-  echo "parameters. For more complex use cases, you need to edit this script." 1>&2
+if [ "$#" -lt "2" ]; then
+  echo "Usage: $0 /path/to/afl_output_dir /path/to/tested_binary [...target params...]" 1>&2
   echo 1>&2
   exit 1
 fi
 
 DIR="$1"
 BIN="$2"
-
+shift
+shift
 
 if [ "$AFL_ALLOW_TMP" = "" ]; then
 
@@ -85,11 +83,33 @@ for crash in $DIR/crashes/id:*; do
   id=`basename -- "$crash" | cut -d, -f1 | cut -d: -f2`
   sig=`basename -- "$crash" | cut -d, -f2 | cut -d: -f2`
 
+  # Grab the args, converting @@ to $crash
+
+  use_args=""
+  use_stdio=1
+
+  for a in $@; do
+
+    if [ "$a" = "@@" ] ; then
+      args="$use_args $crash"
+      unset use_stdio
+    else
+      args="$use_args $a"
+    fi
+
+  done
+
+  # Strip the trailing space
+  use_args="${use_args# }"
+
   echo "+++ ID $id, SIGNAL $sig +++"
   echo
 
-  $GDB --batch -q --ex "r <$crash" --ex 'back' --ex 'disass $pc, $pc+16' --ex 'info reg' --ex 'quit' "$BIN" 0</dev/null
+  if [ "$use_stdio" = "1" ]; then  
+    $GDB --batch -q --ex "r $use_args <$crash" --ex 'back' --ex 'disass $pc, $pc+16' --ex 'info reg' --ex 'quit' "$BIN" 0</dev/null
+  else
+    $GDB --batch -q --ex "r $use_args" --ex 'back' --ex 'disass $pc, $pc+16' --ex 'info reg' --ex 'quit' "$BIN" 0</dev/null
+  fi
   echo
 
 done
-
