@@ -41,9 +41,13 @@ SYNC_DIR='/home/bob/sync_dir'
 # Interval (seconds) between sync attempts
 SYNC_INTERVAL=$((30 * 60))
 
-if [ "$PWD" = "/tmp" -o "$PWD" = "/var/tmp" ]; then
-  echo "[-] Error: do not use shared /tmp or /var/tmp directories with this script." 1>&2
-  exit 1
+if [ "$AFL_ALLOW_TMP" = "" ]; then
+
+  if [ "$PWD" = "/tmp" -o "$PWD" = "/var/tmp" ]; then
+    echo "[-] Error: do not use shared /tmp or /var/tmp directories with this script." 1>&2
+    exit 1
+  fi
+
 fi
 
 rm -rf .sync_tmp 2>/dev/null
